@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ctcp.c,v 1.52 2006/10/31 12:31:27 f Exp $
+ * $Id: ctcp.c,v 1.54 2008-12-01 15:41:36 f Exp $
  */
 
 #include "irc.h"
@@ -91,6 +91,7 @@ extern void EncryptString _((char *, char *, char *, int, int));
 extern void ChannelLogSave _((char *, ChannelList *));
 extern int  AutoReplyMatch _((char *));
 extern void Check4WordKick _((char *, NickList *, int, ChannelList *));
+extern void dcc_reject _((char *, char *, char *));
 /****************************************************************************/
 
 static	char	CTCP_Reply_Buffer[BIG_BUFFER_SIZE + 1] = "";
@@ -1425,10 +1426,10 @@ do_atmosphere(ctcp, from, to, cmd)
         char    *color = "";
 #endif
         char    tmpbuf1[mybufsize / 2];
-        void    (*func)();
+        Window *(*func)();
         ChannelList *chan;
 	NickList *joiner;
-        Window *oldwin;
+        Window *oldwin, *w = NULL;
 
 #ifdef HAVE_ICONV_H
         if (get_int_var(HIGH_ASCII_VAR)) thing = "\342\210\236";
@@ -1436,8 +1437,8 @@ do_atmosphere(ctcp, from, to, cmd)
         if (get_int_var(HIGH_ASCII_VAR)) thing = "";
 #endif /* HAVE_ICONV_H */
         else thing = "*";
-        if (Stamp == 2) func = (void(*)()) say;
-        else func = (void(*)()) put_it;
+        if (Stamp == 2) func = (Window *(*)()) say;
+        else func = (Window *(*)()) put_it;
 /****************************************************************************/
         if (cmd && *cmd)
 	{
@@ -1470,12 +1471,12 @@ do_atmosphere(ctcp, from, to, cmd)
 					put_it("* %s:%s %s", from, to, cmd);*/
 				if (is_current_channel(to, parsing_server_index, 0))
 #ifdef WANTANSI
-                                    func("%s%s%s %s%s%s %s%s%s",
-                                          CmdsColors[COLME].color1, thing, Colors[COLOFF],
-                                          color, from, Colors[COLOFF],
-                                          CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
+                                    w = func("%s%s%s %s%s%s %s%s%s",
+                                             CmdsColors[COLME].color1, thing, Colors[COLOFF],
+                                             color, from, Colors[COLOFF],
+                                             CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
 #else
-                                    func("%s %s%s%s %s", thing, color, from, color, cmd);
+                                    w = func("%s %s%s%s %s", thing, color, from, color, cmd);
 #endif
                                 else {
 #ifdef WANTANSI
@@ -1483,10 +1484,10 @@ do_atmosphere(ctcp, from, to, cmd)
                                            CmdsColors[COLME].color4, to, Colors[COLOFF],
                                            CmdsColors[COLME].color1, thing, Colors[COLOFF],
                                            color, from, Colors[COLOFF]);
-                                    func("%s %s%s%s",tmpbuf1,
-                                          CmdsColors[COLME].color5,cmd, Colors[COLOFF]);
+                                    w = func("%s %s%s%s",tmpbuf1,
+                                             CmdsColors[COLME].color5,cmd, Colors[COLOFF]);
 #else
-                                    func("<%s> %s %s%s%s %s", to, thing, color, from, color, cmd);
+                                    w = func("<%s> %s %s%s%s %s", to, thing, color, from, color, cmd);
 #endif
                                 }
 /****************************************************************************/
@@ -1536,10 +1537,10 @@ do_atmosphere(ctcp, from, to, cmd)
                                     to_window = curr_scr_win;
                             }
 #ifdef WANTANSI
-                            func("%s %s%s%s", tmpbuf1,
-                                 CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
+                            w = func("%s %s%s%s", tmpbuf1,
+                                     CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
 #else
-                            func("%s", tmpbuf1);
+                            w = func("%s", tmpbuf1);
 #endif
                             to_window = oldwin;
                         }
@@ -1558,18 +1559,22 @@ do_atmosphere(ctcp, from, to, cmd)
 /**************************** PATCHED by Flier ******************************/
 				/*put_it("*> %s %s", from, cmd);*/
 #ifdef WANTANSI
-                                func("%s%s%s> %s%s%s %s%s%s",
-                                      CmdsColors[COLME].color1, thing, Colors[COLOFF],
-                                      color, from, Colors[COLOFF],
-                                      CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
+                                w = func("%s%s%s> %s%s%s %s%s%s",
+                                         CmdsColors[COLME].color1, thing, Colors[COLOFF],
+                                         color, from, Colors[COLOFF],
+                                         CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
 #else
-				func("%s> %s%s%s %s", thing, color, from, color, cmd);
+				w = func("%s> %s%s%s %s", thing, color, from, color, cmd);
 #endif
 /****************************************************************************/
 		}
 		set_lastlog_msg_level(old);
  		restore_message_from();
 	}
+        if (foundar && w != curr_scr_win) {
+            w->miscflags |= WINDOW_REPWORD;
+            update_all_status();
+        }
 	return NULL;
 }
 
@@ -1592,9 +1597,20 @@ do_dcc(ctcp, from, to, args)
 
 	if (my_stricmp(to, get_server_nickname(parsing_server_index)))
 		return NULL;
-	if (!(type = next_arg(args, &args)) ||
 /**************************** PATCHED by Flier ******************************/
-			/*!(description = next_arg(args, &args)) ||*/
+        /* handle DCC reject separately */
+	/*if (!(type = next_arg(args, &args)) ||
+			!(description = next_arg(args, &args)) ||*/
+        type = next_arg(args, &args);
+        if (type && !my_stricmp(type, "REJECT")) {
+            char *dcc_type = next_arg(args, &args);
+            char *dcc_file = new_next_arg(args, &args);
+
+            if (dcc_type && dcc_file)
+                dcc_reject(from, dcc_type, dcc_file);
+            return NULL;
+        }
+        else if (!type ||
                         /* support filenames enclosed in quotes */
 			!(description = new_next_arg(args, &args)) ||
 /****************************************************************************/
@@ -2021,7 +2037,7 @@ do_new_notice_ctcp(from, to, str, cmd)
 /**************************** PATCHED by Flier ******************************/
                         /*say("CTCP %s reply from %s: %s", cmd, from,
 				args);*/
-                        if (my_stricmp(cmd,"PING")) {
+                        if (my_stricmp(cmd, "PING") && my_stricmp(cmd, "DCC")) {
 #ifdef WANTANSI
                             say("%sCTCP %s%s reply from %s%s%s: %s",
                                 CmdsColors[COLCTCP].color4,cmd,Colors[COLOFF],
@@ -2030,7 +2046,8 @@ do_new_notice_ctcp(from, to, str, cmd)
                             say("CTCP %s reply from %s: %s",cmd,from,args);
 #endif
                         }
-                        else {
+                        else if (my_stricmp(cmd, "DCC") &&
+                                 my_strnicmp(args, "REJECT ", 7)) {
                             isitme=!my_stricmp(from,get_server_nickname(from_server));
 #ifdef WANTANSI
                             say("%sCTCP %s%s reply from %s%s%s: %s",
