@@ -31,12 +31,12 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: irc.c,v 1.130 2006/10/31 12:31:27 f Exp $
+ * $Id: irc.c,v 1.136 2008-12-29 08:59:13 f Exp $
  */
 
-#define IRCII_VERSION	"20061030"	/* YYYYMMDD */
+#define IRCII_VERSION	"20081231"	/* YYYYMMDD */
 /**************************** PATCHED by Flier ******************************/
-#define SCROLLZ_VERSION "1.9.99"
+#define SCROLLZ_VERSION "2.0"
 /****************************************************************************/
 
 #include "irc.h"
@@ -184,6 +184,7 @@ static	char	*get_arg _((char *, char *, int *));
 static	char	*parse_args _((char **, int));
 
 static	int	cntl_c_hit = 0;
+static	int	connect_at_startup = 1;
 
 /**************************** PATCHED by Flier ******************************
 #ifdef DO_USER2
@@ -214,6 +215,7 @@ static	char	switch_help[] =
    -q\t\tdoes not load .scrollzrc nor .scrollzquick\n\
    -a\t\tadds default servers and command line servers to server list\n\
    -b\t\tload .scrollzrc before connecting to a server\n\
+   -n\t\tdo not connect to a server on startup\n\
    -t\t\tdo not use termcap ti and te sequences at startup\n\
    -T\t\tuse termcap ti and te sequences at startup (default)\n\
    -l <file>\tloads <file> in place of your .scrollzrc\n\
@@ -263,7 +265,7 @@ char  defban;
 char  bold=2;
 char  *DefaultServer=(char *) 0;
 char  *ScrollZstr=(char *) 0;
-char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (30.10.2006)+Cdcc v" CDCC_VERSION;
+char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (30.12.2008)+Cdcc v" CDCC_VERSION;
 char  *ScrollZver1=(char *) 0;
 #ifdef EXTRA_STUFF
 char  *EString=(char *) 0;
@@ -353,10 +355,15 @@ char  *ChanLogDir=(char *) 0;
 char  *ChanLogPrefix=(char *) 0;
 char  *ChanLogPostfix=(char *) 0;
 char  *ExtTopicDelimiter=(char *) 0;
+char  *ShowChanChannels=(char *) 0;
 #ifdef BLAXTHOS
 char  *OperNick=(char *) 0;
 char  *OperPassword=(char *) 0;
 #endif
+#ifdef HAVE_MIRACL
+char  MyPrivKey[mybufsize / 2];
+char  MyPubKey[mybufsize / 2];
+#endif
 int   DeopPrinted;
 int   KickPrinted;
 int   NickPrinted;
@@ -464,6 +471,7 @@ int   ChanLog;
 int   AwayEncrypt;
 int   BanTime;
 int   StatusLines = DEFAULT_STATUS_LINES - 1;
+int   ShowChan;
 #ifdef ACID
 int   ForceJoin;
 #endif
@@ -584,7 +592,7 @@ char VersionInfo[] = {
     'E',
     'R',
 #endif
-#ifdef HAVE_SSL
+#if defined(HAVE_SSL) || defined(HAVE_OPENSSL)
     ' ',
     'S',
     'S',
@@ -597,6 +605,13 @@ char VersionInfo[] = {
     'F',
     '-',
     '8',
+#endif
+#ifdef HAVE_MIRACL
+    ' ',
+    'F',
+    'i',
+    'S',
+    'H',
 #endif
     '\0'};
 /*****************************/
@@ -992,6 +1007,9 @@ parse_args(argv, argc)
 					}
 					qflag = 1;
 					break;
+				case 'n':
+					connect_at_startup = 0;
+					break;
 /**************************** PATCHED by Flier ******************************/
                                 /* what the hell is this */
 				/*case '-':
@@ -1198,6 +1216,7 @@ TimerTimeout(struct timeval *tv)
 {
 	struct timeval current;
 /**************************** PATCHED by Flier ******************************/
+        int do_clock, sec_to_minute;
         time_t nickt = LastNick + OrigNickDelay;
 	struct timeval largest;
 /****************************************************************************/
@@ -1207,9 +1226,11 @@ TimerTimeout(struct timeval *tv)
 
 /**************************** PATCHED by Flier ******************************/
         DoOrigNick = 0;
+        do_clock = get_int_var(CLOCK_VAR);
 	/* If ORIGNICK is off set nickt to current + 75 to prevent excessive
 	   CPU usage (meaning we actually ignore this event, see below) */
 	gettimeofday(&current, NULL);
+        if (do_clock) sec_to_minute = (current.tv_sec / 60 + 1) * 60 - current.tv_sec;
         if (!OrigNickChange) nickt = current.tv_sec + 75;
 /****************************************************************************/
 
@@ -1220,6 +1241,7 @@ TimerTimeout(struct timeval *tv)
                 if (nickt - current.tv_sec < 70) DoOrigNick = 1;
                 tv->tv_sec = nickt - current.tv_sec > 70 ? 70 : nickt - current.tv_sec;
                 if (DoOrigNick && tv->tv_sec <= 0) tv->tv_sec = 70;
+                if (do_clock && sec_to_minute < tv->tv_sec) tv->tv_sec = sec_to_minute;
 /****************************************************************************/
 		return;
 	}
@@ -1234,6 +1256,10 @@ TimerTimeout(struct timeval *tv)
             largest.tv_sec = PendingTimers->time;
             largest.tv_usec = PendingTimers->microseconds;
         }
+        if (do_clock && (sec_to_minute < current.tv_sec + largest.tv_sec)) {
+            largest.tv_sec = current.tv_sec + sec_to_minute;
+            largest.tv_usec = 0;
+        }
 /****************************************************************************/
 
 /**************************** PATCHED by Flier ******************************/
@@ -1858,7 +1884,8 @@ main(argc, argv, envp)
 		load_ircrc();
 	}
 
-	get_connected(0, 0);
+	if (connect_at_startup)
+		get_connected(0, 0);
         if (channel)
 	{
 		char    *ptr;
