@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: parse.c,v 1.77 2006/10/31 12:31:27 f Exp $
+ * $Id: parse.c,v 1.81 2008-03-09 11:18:52 f Exp $
  */
 
 #include "irc.h"
@@ -102,6 +102,7 @@ extern char *TimeStamp _((int));
 extern void ChannelLogSave _((char *, ChannelList *));
 extern void SendToServer _((void));
 extern int  RateLimitJoin _((int));
+extern char *OpenCreateFile _((char *, int));
 
 extern void e_nick _((char *, char *, char *));
 extern void e_channel _((char *, char *, char *));
@@ -315,6 +316,16 @@ p_topic(from, ArgList)
                 ChannelLogSave(tmpbuf, chan);
             }
         }
+        if (URLCatch) {
+            int numurl;
+            char tmpbuf2[mybufsize];
+            char tmpbuf3[mybufsize / 2];
+            char *filepath = NULL;
+
+            snprintf(tmpbuf3, sizeof(tmpbuf3), "%s topic %s", from, ArgList[0]);
+            filepath = OpenCreateFile("ScrollZ.notepad", 1);
+            numurl = GrabURL(ArgList[1], tmpbuf2, filepath, tmpbuf3);
+        }
         if ((double_ignore(ArgList[0], NULL, IGNORE_CRAP)) == IGNORED) return;
         if ((double_ignore(FromUserHost, ArgList[0], IGNORE_CRAP)) == IGNORED) return;
 /****************************************************************************/				
@@ -339,18 +350,29 @@ p_topic(from, ArgList)
 	}
 	else
 	{
+/**************************** PATCHED by Flier ******************************/
+                int iscrypted;
+                char *cstr = "";
+                char tmpbuf[BIG_BUFFER_SIZE + 1];
+
+                strmcpy(tmpbuf, ArgList[1], sizeof(tmpbuf));
+                iscrypted = DecryptMessage(tmpbuf, ArgList[0]);
+                if (iscrypted == 2) cstr = "[*]";
+                else if (iscrypted) cstr = "[!]";
+/****************************************************************************/
+
 		message_from(ArgList[0], LOG_CRAP);
-		if (do_hook(TOPIC_LIST, "%s %s %s", from, ArgList[0], ArgList[1]))
+		if (do_hook(TOPIC_LIST, "%s %s %s", from, ArgList[0], tmpbuf))
 /**************************** PATCHED by Flier ******************************/
 			/*say("%s has changed the topic on channel %s to %s",
 				from, ArgList[0], ArgList[1]);*/
                 {
                         if (*ArgList[1])
-                            say("%s has set the topic on channel %s to %s",
-                                    from, ArgList[0], ArgList[1]);
+                            say("%s has set the topic on channel %s%s to %s",
+                                    from, cstr, ArgList[0], ArgList[1]);
                         else
-                            say("%s has unset the topic on channel %s",
-                                    from, ArgList[0]);
+                            say("%s has unset the topic on channel %s%s",
+                                    from, cstr, ArgList[0]);
                 }
 /****************************************************************************/
 	}
@@ -497,7 +519,7 @@ whoreply(from, ArgList)
         int     show_server = 0;
 /****************************************************************************/
 
-	FILE	*fip;
+	FILE	*fip = NULL;
 	char	buf_data[BUFSIZ];
 
 	if (last_width != get_int_var(CHANNEL_NAME_WIDTH_VAR))
@@ -528,12 +550,14 @@ whoreply(from, ArgList)
  	if (*status == 'S')	/* this only true for the header WHOREPLY */
 	{
 		channel = "Channel";
-		if (((who_mask & WHO_FILE) == 0) || (fopen (who_file, "r")))
+		if (((who_mask & WHO_FILE) == 0) || (fip = fopen (who_file, "r")))
 		{
 			if (do_hook(WHO_LIST, "%s %s %s %s %s %s", channel,
  					nick, status, user, host, ArgList[6]))
  				put_it(format, channel, nick, status, user,
 					host, ArgList[6]);
+			if (fip)
+				fclose(fip);
 			return;
 		}
 	}
