@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: screen.c,v 1.39 2006/10/31 12:31:27 f Exp $
+ * $Id: screen.c,v 1.42 2008-12-01 15:41:36 f Exp $
  */
 
 #include "irc.h"
@@ -686,7 +686,7 @@ display_text(ustr, length)
 /**************************** PATCHED by Flier ******************************/
 #ifdef WANTANSI
                                 else if ((*str == '\033') && (len == 1)) {
-                                    int ansi_count;
+                                    int ansi_count = 0;
                                     char *orig_str = str;
 
                                     if (outptr >= OutBuf + sizeof(OutBuf)) {
@@ -1604,6 +1604,8 @@ split_up_line(str)
 		invert_state = 0,
 		underline_state = 0;
 /**************************** PATCHED by Flier ******************************/
+        int     iso2022 = get_int_var(ISO2022_SUPPORT_VAR);
+        int     isiso;
 #ifdef WANTANSI
         int     ansi_count;
 #endif /* WANTANSI */
@@ -1695,15 +1697,32 @@ split_up_line(str)
 			break;
 /**************************** PATCHED by Flier ******************************/
 #ifdef WANTANSI
+                        /* XXX: flier fix for ISO-2022-JP */
                 case '\033':
                         ansi_count = 0;
-                        while (vt100Decode(*ptr)) {
+                        isiso = 0;
+                        while ((c = vt100Decode(*ptr))) {
+                            /* terminate on escape if ISO-2022-JP support is enabled */
+                            if (iso2022 && *ptr == '\033' && ansi_count) break;
+                            if (c > 1) isiso = 1;
                             lbuf[pos++] = *ptr;
                             nd_cnt++;
                             ptr++;
                             ansi_count++;
                         }
-                        if (ansi_count) ptr--;
+                        if (isiso || ansi_count) ptr--;
+                        if (ansi_count && iso2022 && isiso) {
+                            char lbuf2[BIG_BUFFER_SIZE];
+                            char lbuf3[BIG_BUFFER_SIZE];
+
+                            memcpy(lbuf2, lbuf + pos - ansi_count, ansi_count);
+                            lbuf2[ansi_count] = '\0';
+                            pos -= ansi_count;
+                            nd_cnt -= ansi_count;
+
+                            /* FIXME: No array bound checking - very insecure */
+                            decode_mb(lbuf2, lbuf3, &mbdata);
+                        }
                         break;
 #endif /* WANTANSI */
                 case '|':       /* possible word break if time stamp is set to max */
@@ -1929,12 +1948,12 @@ int in_redirect;
  * lastlog the information should be added to, which log the information
  * should be sent to, etc 
  */
-void
+Window *
 add_to_screen(incoming)
 	char	*incoming;
 {
 	int	flag;
-	Window	*tmp;
+	Window	*tmp, *w = NULL;
 	char	buffer[BIG_BUFFER_SIZE + 1];
 /**************************** PATCHED by Flier ******************************/
         char tmpbuf[BIG_BUFFER_SIZE + 1];
@@ -2015,22 +2034,25 @@ add_to_screen(incoming)
 	{
 		/* FIXME: Do iconv for "incoming" in dumb mode too */
 		add_to_lastlog(curr_scr_win, incoming);
+                w = curr_scr_win;
 		if (do_hook(WINDOW_LIST, "%u %s", curr_scr_win->refnum, incoming))
 			puts(incoming);
   		term_flush();
-		return;
+		return w;
 	}
 	if (in_window_command)
 		update_all_windows();
 	if ((who_level == LOG_CURRENT) && (curr_scr_win->server == from_server))
         {
 		add_to_window(curr_scr_win, incoming);
-		return;
+                w = curr_scr_win;
+		return w;
 	}
 	if (to_window)
 	{
 		add_to_window(to_window, incoming);
-		return;
+                w = to_window;
+		return w;
 	}
 	if (who_from)
 	{
@@ -2041,7 +2063,8 @@ add_to_screen(incoming)
 			if ((chan = lookup_channel(who_from, from_server, CHAN_NOUNLINK)))
 			{
 				add_to_window(chan->window ? chan->window : curr_scr_win, incoming);
-				return;
+                                w = chan->window ? chan->window : curr_scr_win;
+				return w;
 			}
 			if (who_level == LOG_DCC)
 			{
@@ -2050,7 +2073,8 @@ add_to_screen(incoming)
 				if ((chan = lookup_channel(buffer, from_server, CHAN_NOUNLINK)))
 				{
 					add_to_window(chan->window ? chan->window : curr_scr_win, incoming);
-					return;
+                                        w = chan->window ? chan->window : curr_scr_win;
+					return w;
 				}
 			}
 		}
@@ -2068,7 +2092,8 @@ add_to_screen(incoming)
 					my_stricmp(who_from, tmp->query_nick + 1) == 0)))
 				{
 					add_to_window(tmp, incoming);
-					return;
+                                        w = tmp;
+					return w;
 				}
 			}
 			flag = 1;
@@ -2079,7 +2104,8 @@ add_to_screen(incoming)
 					if (find_in_list((List **) &(tmp->nicks), who_from, !USE_WILDCARDS))
 					{
 						add_to_window(tmp, incoming);
-						return;
+                                                w = tmp;
+						return w;
 					}
 				}
 			}
@@ -2092,7 +2118,8 @@ add_to_screen(incoming)
 		    (who_level & tmp->window_level))
 		{
 			add_to_window(tmp, incoming);
-			return;
+                        w = tmp;
+			return w;
 		}
 	}
 	if (from_server == curr_scr_win->server)
@@ -2109,6 +2136,8 @@ add_to_screen(incoming)
 			tmp = curr_scr_win;
 	}
 	add_to_window(tmp, incoming);
+        w = tmp;
+        return w;
 }
 
 /*
