@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: vars.c,v 1.29 2006/10/31 12:31:27 f Exp $
+ * $Id: vars.c,v 1.37 2008-12-01 15:41:36 f Exp $
  */
 
 #include "irc.h"
@@ -61,18 +61,6 @@ extern char *TimeStampString;
 extern time_t LastTS;
 /****************************************************************************/
 
-/* IrcVariable: structure for each variable in the variable table */
-typedef struct
-{
-	char	*name;			/* what the user types */
-	int	type;			/* variable types, see below */
-	int	integer;		/* int value of variable */
-	char	*string;		/* string value of variable */
- 	void	(*func) ();		/* function to do every time variable is set */
-	char	int_flags;		/* internal flags to the variable */
-	unsigned short	flags;		/* flags for this variable */
-}	IrcVariable;
-
 #define	VF_NODAEMON	0x0001
 #define VF_EXPAND_PATH	0x0002
 
@@ -132,11 +120,12 @@ extern	char	*CelerityNtfy;
  * check_variable_order() procedure will assert that it is from
  * init_variables()
  */
-static	IrcVariable irc_variable[] =
+IrcVariable irc_variable[] =
 {
 	{ "ALWAYS_SPLIT_BIGGEST",	BOOL_TYPE_VAR,	DEFAULT_ALWAYS_SPLIT_BIGGEST, NULL, NULL, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
 	{ "AUTO_RECONNECT",		BOOL_TYPE_VAR,	DEFAULT_AUTO_RECONNECT, NULL, NULL, 0, 0 },
+	{ "AUTO_RECONNECT_CHANNELS",	BOOL_TYPE_VAR,	DEFAULT_AUTO_RECONNECT_CHANNELS, NULL, NULL, 0, 0 },
 /****************************************************************************/
 	{ "AUTO_UNMARK_AWAY",		BOOL_TYPE_VAR,	DEFAULT_AUTO_UNMARK_AWAY, NULL, NULL, 0, 0 },
 	{ "AUTO_WHOWAS",		BOOL_TYPE_VAR,	DEFAULT_AUTO_WHOWAS, NULL, NULL, 0, 0 },
@@ -151,6 +140,9 @@ static	IrcVariable irc_variable[] =
 	{ "BEEP_ON_MSG",		STR_TYPE_VAR,	0, NULL, set_beep_on_msg, 0, 0 },
 	{ "BEEP_WHEN_AWAY",		INT_TYPE_VAR,	DEFAULT_BEEP_WHEN_AWAY, NULL, NULL, 0, 0 },
 	{ "BOLD_VIDEO",			BOOL_TYPE_VAR,	DEFAULT_BOLD_VIDEO, NULL, NULL, 0, 0 },
+/**************************** PATCHED by Flier ******************************/
+	{ "CHANLOG_STRIP_ANSI",		BOOL_TYPE_VAR,	DEFAULT_CHANLOG_STRIP_ANSI, NULL, NULL, 0, 0 },
+/****************************************************************************/
 	{ "CHANNEL_NAME_WIDTH",		INT_TYPE_VAR,	DEFAULT_CHANNEL_NAME_WIDTH, NULL, update_all_status, 0, 0 },
 	{ "CLIENT_INFORMATION",		STR_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "CLOCK",			BOOL_TYPE_VAR,	DEFAULT_CLOCK, NULL, update_all_status, 0, 0 },
@@ -215,6 +207,9 @@ static	IrcVariable irc_variable[] =
 	{ "INVERSE_VIDEO",		BOOL_TYPE_VAR,	DEFAULT_INVERSE_VIDEO, NULL, NULL, 0, 0 },
 	{ "IRCHOST",			STR_TYPE_VAR,	0, NULL, set_irchost, 0, 0 },
 	{ "IRC_ENCODING",		STR_TYPE_VAR,	0, NULL, set_irc_encoding, 0, 0 },
+/**************************** PATCHED by Flier ******************************/
+        { "ISO2022_SUPPORT",		BOOL_TYPE_VAR,	DEFAULT_ISO2022_SUPPORT, NULL, NULL, 0, 0 },
+/****************************************************************************/
 	{ "LASTLOG",			INT_TYPE_VAR,	DEFAULT_LASTLOG, NULL, set_lastlog_size, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
         { "LASTLOG_ANSI",		BOOL_TYPE_VAR,	1, NULL, NULL, 0, 0 },
@@ -239,10 +234,12 @@ static	IrcVariable irc_variable[] =
 #endif
 	{ "MINIMUM_SERVERS",		INT_TYPE_VAR,	DEFAULT_MINIMUM_SERVERS, NULL, NULL, 0, VF_NODAEMON },
 	{ "MINIMUM_USERS",		INT_TYPE_VAR,	DEFAULT_MINIMUM_USERS, NULL, NULL, 0, VF_NODAEMON },
+	{ "NETSPLIT_TIME",		INT_TYPE_VAR,	DEFAULT_NETSPLIT_TIME, NULL, NULL, 0, 0 },
 	{ "NOTIFY_HANDLER",		STR_TYPE_VAR, 	0, 0, set_notify_handler, 0, 0 },
 	{ "NOTIFY_LEVEL",		STR_TYPE_VAR,	0, NULL, set_notify_level, 0, 0 },
 	{ "NOTIFY_ON_TERMINATION",	BOOL_TYPE_VAR,	DEFAULT_NOTIFY_ON_TERMINATION, NULL, NULL, 0, VF_NODAEMON },
 /**************************** PATCHED by Flier ******************************/
+	{ "NOTIFY_SHOW_NAME",		BOOL_TYPE_VAR,	DEFAULT_NOTIFY_SHOW_NAME, NULL, NULL, 0, 0 },
 	{ "NOTIFY_STRING",		STR_TYPE_VAR,	0, NULL, Cnotifystring, 0, 0 },
 /****************************************************************************/
 	{ "NOVICE",			BOOL_TYPE_VAR,	DEFAULT_NOVICE, NULL, NULL, 0, 0 },
@@ -258,6 +255,9 @@ static	IrcVariable irc_variable[] =
 /****************************************************************************/
 	{ "SCROLL_LINES",		INT_TYPE_VAR,	DEFAULT_SCROLL_LINES, NULL, set_scroll_lines, 0, 0 },
 	{ "SEND_IGNORE_MSG",		BOOL_TYPE_VAR,	DEFAULT_SEND_IGNORE_MSG, NULL, NULL, 0, 0 },
+/**************************** PATCHED by Flier ******************************/
+        { "SEND_USERHOST_ON_NICK_IN_USE",BOOL_TYPE_VAR, 0, NULL, NULL, 0, 0 },
+/****************************************************************************/
 	{ "SHELL",			STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "SHELL_FLAGS",		STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "SHELL_LIMIT",		INT_TYPE_VAR,	DEFAULT_SHELL_LIMIT, NULL, NULL, 0, VF_NODAEMON },
@@ -294,6 +294,8 @@ static	IrcVariable irc_variable[] =
 	{ "STATUS_MAIL",		STR_TYPE_VAR,	0, NULL, build_status, 0, VF_NODAEMON },
 	{ "STATUS_MODE",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 	{ "STATUS_NOTIFY",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
+	{ "STATUS_NOTIFY_REPW_END_VAR",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
+	{ "STATUS_NOTIFY_REPW_START_VAR",	STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 	{ "STATUS_OPER",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 	{ "STATUS_OVERWRITE",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 	{ "STATUS_QUERY",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
