@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: window.c,v 1.45 2005/08/08 18:50:47 f Exp $
+ * $Id: window.c,v 1.48 2008-12-01 15:41:36 f Exp $
  */
 
 #include "irc.h"
@@ -87,7 +87,7 @@ extern	char	*redirect_nick;
 
 /**************************** PATCHED by Flier ******************************/
 extern NickList *tabnickcompl;
-#ifdef HAVE_SSL
+#if defined(HAVE_SSL) || defined(HAVE_OPENSSL)
 extern int SSLconnect;
 #endif
 /****************************************************************************/
@@ -533,6 +533,7 @@ remove_from_invisible_list(window)
 	window->visible = 1;
 	window->screen = current_screen;
 	window->miscflags &= ~WINDOW_NOTIFIED;
+	window->miscflags &= ~WINDOW_REPWORD;
 	if (window->prev)
 		window->prev->next = window->next;
 	else
@@ -2892,7 +2893,7 @@ windowcmd(command, args, subargs)
 			grow_window(window, get_number("GROW", &args));
 		else if (strncmp("SIZE", cmd, len) == 0)
 			size_window(window, get_number("SIZE", &args));
-#ifdef HAVE_SSL
+#if defined(HAVE_SSL) || defined(HAVE_OPENSSL)
 		else if (strncmp("SSL", cmd, len) == 0 || strncmp("-SSL", cmd, len) == 0)
 			SSLconnect = 1;
 #endif
@@ -3017,6 +3018,13 @@ windowcmd(command, args, subargs)
 			else
 				say("You must specify a name for the window!");
 		}
+/**************************** PATCHED by Flier ******************************/
+                else if (strncmp("UNNAME", cmd, len) == 0)
+                {
+                    new_free(&(window->name));
+                    update_window_status(window, 0);
+                }
+/****************************************************************************/
 		else if (strncmp("PROMPT", cmd, len) == 0)
 		{
 			if ((arg = next_arg(args, &args)) != NULL)
@@ -3423,7 +3431,7 @@ out:
 	update_all_windows();
         cursor_to_input();
 /**************************** Patched by Flier ******************************/
-#ifdef HAVE_SSL
+#if defined(HAVE_SSL) || defined(HAVE_OPENSSL)
         SSLconnect = 0;
 #endif
 /****************************************************************************/
